"use client"

import { useState, useEffect } from "react"
import { useRouter } from "next/navigation"
import { useAuth } from "@/contexts/auth-context"
import { useLanguage } from "@/contexts/language-context"
import type { Store, GroceryItem } from "@/types"
import {
  Loader2,
  ArrowRight,
  Star,
  ShoppingCart,
  Zap,
  Bell,
  Check,
  Share,
  Shield,
  Smartphone,
  CreditCard,
  Mail,
  Phone,
  MessageSquare,
  Send,
  Twitter,
  Facebook,
  Instagram,
  Github,
} from "lucide-react"
import { Button } from "@/components/ui/button"
import { useToast } from "@/hooks/use-toast"
import { motion } from "framer-motion"
import Image from "next/image"
import Dashboard from "@/components/dashboard"
import { Badge } from "@/components/ui/badge"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { Label } from "@/components/ui/label"
import { Input } from "@/components/ui/input"
import { Textarea } from "@/components/ui/textarea"

export default function Home() {
  const { user, loading } = useAuth()
  const router = useRouter()
  const { toast } = useToast()
  const { t } = useLanguage()

  const [stores, setStores] = useState<Store[]>([])
  const [items, setItems] = useState<GroceryItem[]>([])
  const [selectedStoreId, setSelectedStoreId] = useState<string | null>(null)
  const [isClient, setIsClient] = useState(false)

  // Set isClient to true on mount
  useEffect(() => {
    setIsClient(true)
  }, [])

  // Load data from localStorage when user and isClient are available
  useEffect(() => {
    if (isClient && user) {
      const savedStores = localStorage.getItem(`groceryStores_${user.uid}`)
      const savedItems = localStorage.getItem(`groceryItems_${user.uid}`)
      if (savedStores) {
        const parsedStores = JSON.parse(savedStores)
        setStores(parsedStores)
      } else {
        setStores([])
      }
      if (savedItems) {
        setItems(JSON.parse(savedItems))
      } else {
        setItems([])
      }
    }
  }, [isClient, user])

  // Select the first store when stores change
  useEffect(() => {
    if (stores.length > 0 && !selectedStoreId) {
      setSelectedStoreId(stores[0].id)
    } else if (stores.length === 0) {
      setSelectedStoreId(null)
    }
  }, [stores, selectedStoreId])

  // Save stores to localStorage
  useEffect(() => {
    if (isClient && user) {
      localStorage.setItem(`groceryStores_${user.uid}`, JSON.stringify(stores))
    }
  }, [stores, isClient, user])

  // Save items to localStorage
  useEffect(() => {
    if (isClient && user) {
      localStorage.setItem(`groceryItems_${user.uid}`, JSON.stringify(items))
    }
  }, [items, isClient, user])

  const addStore = (name: string) => {
    if (!name.trim()) return
    const newStore: Store = { id: crypto.randomUUID(), name: name.trim() }
    const updatedStores = [...stores, newStore]
    setStores(updatedStores)
    setSelectedStoreId(newStore.id)
  }

  const deleteStore = (id: string) => {
    const updatedStores = stores.filter((store) => store.id !== id)
    const updatedItems = items.filter((item) => item.storeId !== id)
    setStores(updatedStores)
    setItems(updatedItems)
  }

  const addItem = (name: string, quantity: number, buyOnSaleOnly: boolean) => {
    if (!name.trim() || !selectedStoreId || quantity <= 0) return
    const newItem: GroceryItem = {
      id: crypto.randomUUID(),
      name: name.trim(),
      quantity,
      storeId: selectedStoreId,
      purchased: false,
      buyOnSaleOnly,
    }
    setItems([...items, newItem])
  }

  const toggleItemPurchased = (id: string) => {
    setItems(items.map((item) => (item.id === id ? { ...item, purchased: !item.purchased } : item)))
  }

  const toggleItemSaleOnly = (id: string) => {
    setItems(items.map((item) => (item.id === id ? { ...item, buyOnSaleOnly: !item.buyOnSaleOnly } : item)))
  }

  const deleteItem = (id: string) => {
    setItems(items.filter((item) => item.id !== id))
  }

  const updateItemQuantity = (id: string, change: number) => {
    setItems(items.map((item) => (item.id === id ? { ...item, quantity: Math.max(1, item.quantity + change) } : item)))
  }

  const filteredItems = items.filter((item) => item.storeId === selectedStoreId)
  const selectedStore = stores.find((store) => store.id === selectedStoreId)

  if (loading) {
    return (
      <div className="flex justify-center items-center min-h-[calc(100vh-4rem)]">
        <Loader2 className="h-12 w-12 animate-spin text-emerald-500" />
      </div>
    )
  }

  if (user) {
    return <Dashboard />
  }

  // Modernized Landing Page for unauthenticated users
  return (
    <div className="bg-gradient-to-b from-slate-950 via-slate-900 to-slate-800 text-white min-h-screen font-sans">
      {/* Hero Section */}
      <section className="relative overflow-hidden py-20">
        {/* Animated background elements */}
        <div className="absolute inset-0 z-0">
          <motion.div
            initial={{ opacity: 0.2, x: -100 }}
            animate={{ opacity: 0.2, x: 0 }}
            transition={{ duration: 1.5 }}
            className="absolute top-20 left-10 w-72 h-72 bg-emerald-500 rounded-full filter blur-3xl"
          />
          <motion.div
            initial={{ opacity: 0.2, x: 100 }}
            animate={{ opacity: 0.2, x: 0 }}
            transition={{ duration: 1.5 }}
            className="absolute bottom-20 right-10 w-80 h-80 bg-teal-500 rounded-full filter blur-3xl"
          />

          {/* Floating shapes */}
          <div className="absolute inset-0 overflow-hidden">
            {[...Array(6)].map((_, i) => (
              <motion.div
                key={i}
                className="absolute"
                initial={{
                  x: Math.random() * window.innerWidth,
                  y: Math.random() * window.innerHeight,
                  scale: Math.random() * 0.5 + 0.5,
                  opacity: 0.1,
                }}
                animate={{
                  y: [null, Math.random() * 100 - 50],
                  rotate: [0, Math.random() * 360],
                }}
                transition={{
                  duration: Math.random() * 10 + 10,
                  repeat: Number.POSITIVE_INFINITY,
                  repeatType: "reverse",
                  ease: "easeInOut",
                }}
              >
                <div
                  className={`w-24 h-24 ${i % 2 === 0 ? "bg-emerald-400" : "bg-teal-400"} opacity-10 rounded-${i % 3 === 0 ? "full" : "md"}`}
                />
              </motion.div>
            ))}
          </div>
        </div>

        <div className="container mx-auto pt-28 pb-24 px-6 relative z-10">
          <div className="grid grid-cols-1 lg:grid-cols-2 gap-16 items-center">
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.6, ease: "easeOut" }}
              className="space-y-8"
            >
              <motion.div
                initial={{ opacity: 0, scale: 0.8 }}
                animate={{ opacity: 1, scale: 1 }}
                transition={{ delay: 0.2, duration: 0.5 }}
              >
                <Badge className="px-4 py-1.5 text-sm font-medium bg-emerald-500/20 text-emerald-300 border-emerald-500/30 mb-4">
                  <motion.span
                    animate={{ opacity: [1, 0.7, 1] }}
                    transition={{ duration: 2, repeat: Number.POSITIVE_INFINITY }}
                  >
                    {t("simplifyYourShopping") || "Simplify Your Shopping"}
                  </motion.span>
                </Badge>
              </motion.div>

              <h1 className="text-5xl md:text-6xl font-bold tracking-tight leading-tight">
                {t("smartShopping") || "Smart Shopping"}{" "}
                <motion.span
                  className="text-transparent bg-clip-text bg-gradient-to-r from-emerald-400 to-teal-400 inline-block"
                  animate={{
                    backgroundPosition: ["0% center", "100% center", "0% center"],
                  }}
                  transition={{
                    duration: 8,
                    repeat: Number.POSITIVE_INFINITY,
                    repeatType: "reverse",
                  }}
                  style={{
                    backgroundSize: "200% auto",
                  }}
                >
                  {t("madeSimple") || "Made Simple"}
                </motion.span>
              </h1>

              <motion.p
                className="text-xl text-slate-300 max-w-md leading-relaxed"
                initial={{ opacity: 0 }}
                animate={{ opacity: 1 }}
                transition={{ delay: 0.4, duration: 0.6 }}
              >
                {t("landingTagline") ||
                  "Organize your shopping lists, sync across devices, and never miss a deal again."}
              </motion.p>

              <motion.div
                className="flex flex-col sm:flex-row gap-4 pt-4"
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                transition={{ delay: 0.6, duration: 0.6 }}
              >
                <motion.div whileHover={{ scale: 1.05 }} whileTap={{ scale: 0.95 }}>
                  <Button
                    size="lg"
                    className="bg-gradient-to-r from-emerald-600 to-teal-600 hover:from-emerald-700 hover:to-teal-700 text-white font-semibold py-6 px-8 rounded-xl shadow-lg hover:shadow-emerald-500/20 transition-all duration-300"
                    onClick={() => router.push("/auth")}
                  >
                    <motion.span className="flex items-center">
                      {t("getStarted") || "Get Started Free"}
                      <motion.div
                        animate={{ x: [0, 5, 0] }}
                        transition={{ duration: 1, repeat: Number.POSITIVE_INFINITY, repeatDelay: 1 }}
                      >
                        <ArrowRight className="ml-2 h-5 w-5" />
                      </motion.div>
                    </motion.span>
                  </Button>
                </motion.div>

                <motion.div whileHover={{ scale: 1.05 }} whileTap={{ scale: 0.95 }}>
                  <Button
                    variant="outline"
                    size="lg"
                    className="border-2 border-slate-700 bg-slate-800/50 text-white hover:bg-slate-700/50 font-semibold py-6 px-8 rounded-xl transition-all duration-300"
                    onClick={() => router.push("/auth?tab=signin")}
                  >
                    {t("login") || "Log In"}
                  </Button>
                </motion.div>
              </motion.div>

              <motion.div
                className="pt-6 flex items-center text-slate-400 text-sm"
                initial={{ opacity: 0 }}
                animate={{ opacity: 1 }}
                transition={{ delay: 0.8, duration: 0.6 }}
              >
                <motion.div
                  animate={{ scale: [1, 1.2, 1] }}
                  transition={{ duration: 2, repeat: Number.POSITIVE_INFINITY }}
                >
                  <Check className="h-4 w-4 mr-2 text-emerald-500" />
                </motion.div>
                <span>{t("noCreditCardRequired") || "No credit card required"}</span>
                <span className="mx-3">•</span>
                <motion.div
                  animate={{ scale: [1, 1.2, 1] }}
                  transition={{ duration: 2, repeat: Number.POSITIVE_INFINITY, delay: 1 }}
                >
                  <Check className="h-4 w-4 mr-2 text-emerald-500" />
                </motion.div>
                <span>{t("freeForeverPlan") || "Free forever plan"}</span>
              </motion.div>
            </motion.div>

            <motion.div
              initial={{ opacity: 0, scale: 0.95 }}
              animate={{ opacity: 1, scale: 1 }}
              transition={{ duration: 0.7, delay: 0.2 }}
              className="relative hidden lg:block"
            >
              <motion.div
                animate={{
                  boxShadow: [
                    "0 20px 80px -10px rgba(16, 185, 129, 0.1)",
                    "0 20px 80px -10px rgba(16, 185, 129, 0.3)",
                    "0 20px 80px -10px rgba(16, 185, 129, 0.1)",
                  ],
                }}
                transition={{ duration: 4, repeat: Number.POSITIVE_INFINITY }}
                className="relative w-full max-w-[700px] aspect-[4/3] rounded-2xl overflow-hidden border border-slate-700/50"
              >
                <div className="absolute inset-0 bg-gradient-to-br from-slate-800/80 via-transparent to-transparent z-10"></div>
                <Image
                  src="/app-preview.png"
                  alt={t("appPreview") || "App Preview"}
                  fill
                  className="object-cover"
                  priority
                />

                {/* Floating UI elements for visual appeal */}
                <motion.div
                  className="absolute top-8 right-8 bg-white/10 backdrop-blur-md rounded-lg p-3 border border-white/20 shadow-xl z-20"
                  initial={{ y: -20, opacity: 0 }}
                  animate={{ y: 0, opacity: 1 }}
                  transition={{ delay: 0.5, duration: 0.5 }}
                  whileHover={{ y: -5, scale: 1.05 }}
                >
                  <ShoppingCart className="h-6 w-6 text-emerald-400" />
                </motion.div>

                <motion.div
                  className="absolute bottom-8 left-8 bg-white/10 backdrop-blur-md rounded-lg p-3 border border-white/20 shadow-xl z-20"
                  initial={{ y: 20, opacity: 0 }}
                  animate={{ y: 0, opacity: 1 }}
                  transition={{ delay: 0.8, duration: 0.5 }}
                  whileHover={{ y: 5, scale: 1.05 }}
                >
                  <Zap className="h-6 w-6 text-teal-400" />
                </motion.div>

                {/* Notification popup */}
                <motion.div
                  className="absolute top-1/4 left-1/4 bg-white/15 backdrop-blur-md rounded-lg p-4 border border-white/20 shadow-xl z-20 max-w-[200px]"
                  initial={{ opacity: 0, scale: 0.8 }}
                  animate={{ opacity: [0, 1, 1, 0], scale: [0.8, 1, 1, 0.8], y: [20, 0, 0, -20] }}
                  transition={{ delay: 1.5, duration: 5, repeat: Number.POSITIVE_INFINITY, repeatDelay: 10 }}
                >
                  <div className="flex items-start gap-3">
                    <div className="p-2 bg-emerald-500/20 rounded-full">
                      <Bell className="h-4 w-4 text-emerald-400" />
                    </div>
                    <div className="text-xs text-white">
                      <p className="font-medium">{t("priceAlert") || "Price Alert!"}</p>
                      <p className="opacity-80 text-xs">{t("milkOnSale") || "Milk is on sale at Grocery Store"}</p>
                    </div>
                  </div>
                </motion.div>
              </motion.div>

              {/* Decorative elements */}
              <motion.div
                className="absolute -bottom-6 -right-6 w-24 h-24 bg-gradient-to-br from-emerald-500 to-teal-500 rounded-full opacity-50 blur-2xl"
                animate={{ scale: [1, 1.2, 1] }}
                transition={{ duration: 4, repeat: Number.POSITIVE_INFINITY }}
              />
              <motion.div
                className="absolute -top-6 -left-6 w-20 h-20 bg-gradient-to-br from-teal-500 to-emerald-500 rounded-full opacity-50 blur-2xl"
                animate={{ scale: [1, 1.3, 1] }}
                transition={{ duration: 4, repeat: Number.POSITIVE_INFINITY, delay: 1 }}
              />
            </motion.div>
          </div>
        </div>
      </section>

      {/* Features Section */}
      <section className="py-24 relative overflow-hidden">
        {/* Background pattern */}
        <div className="absolute inset-0 opacity-5">
          <div
            className="absolute inset-0"
            style={{
              backgroundImage:
                "url(\"data:image/svg+xml,%3Csvg width='60' height='60' viewBox='0 0 60 60' xmlns='http://www.w3.org/2000/svg'%3E%3Cg fill='none' fillRule='evenodd'%3E%3Cg fill='%2310b981' fillOpacity='0.2'%3E%3Cpath d='M36 34v-4h-2v4h-4v2h4v4h2v-4h4v-2h-4zm0-30V0h-2v4h-4v2h4v4h2V6h4V4h-4zM6 34v-4H4v4H0v2h4v4h2v-4h4v-2H6zM6 4V0H4v4H0v2h4v4h2V6h4V4H6z'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E\")",
              backgroundSize: "60px 60px",
            }}
          ></div>
        </div>

        <div className="container mx-auto px-6 relative z-10">
          <motion.div
            className="text-center max-w-3xl mx-auto mb-16"
            initial={{ opacity: 0, y: 20 }}
            whileInView={{ opacity: 1, y: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.6 }}
          >
            <motion.div
              initial={{ scale: 0.9, opacity: 0 }}
              whileInView={{ scale: 1, opacity: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.5 }}
            >
              <Badge className="px-4 py-1.5 text-sm font-medium bg-slate-800 text-slate-300 border-slate-700 mb-4">
                {t("features") || "Features"}
              </Badge>
            </motion.div>
            <motion.h2
              className="text-4xl font-bold mb-6"
              initial={{ opacity: 0 }}
              whileInView={{ opacity: 1 }}
              viewport={{ once: true }}
              transition={{ delay: 0.2, duration: 0.6 }}
            >
              {t("featuresTitle") || "Everything you need to shop smarter"}
            </motion.h2>
            <motion.p
              className="text-slate-400 text-lg"
              initial={{ opacity: 0 }}
              whileInView={{ opacity: 1 }}
              viewport={{ once: true }}
              transition={{ delay: 0.3, duration: 0.6 }}
            >
              {t("featuresSubtitle") ||
                "Our intuitive platform helps you organize, track, and optimize your shopping experience."}
            </motion.p>
          </motion.div>

          <Tabs defaultValue="organize" className="w-full max-w-4xl mx-auto">
            <motion.div
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              viewport={{ once: true }}
              transition={{ delay: 0.4, duration: 0.6 }}
            >
              <TabsList className="grid grid-cols-4 mb-12 bg-slate-800/50 p-1 rounded-lg">
                {[
                  { value: "organize", label: t("organize") || "Organize" },
                  { value: "sync", label: t("sync") || "Sync" },
                  { value: "track", label: t("track") || "Track" },
                  { value: "save", label: t("save") || "Save" },
                ].map((tab) => (
                  <motion.div key={tab.value} whileHover={{ scale: 1.05 }} whileTap={{ scale: 0.95 }}>
                    <TabsTrigger
                      value={tab.value}
                      className="data-[state=active]:bg-slate-700 data-[state=active]:text-white rounded-md"
                    >
                      {tab.label}
                    </TabsTrigger>
                  </motion.div>
                ))}
              </TabsList>
            </motion.div>

            <motion.div
              className="mt-8 bg-slate-900/30 rounded-2xl border border-slate-800 overflow-hidden"
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              viewport={{ once: true }}
              transition={{ delay: 0.5, duration: 0.6 }}
            >
              <TabsContent value="organize" className="p-0 m-0">
                <div className="grid grid-cols-1 md:grid-cols-2 items-center">
                  <motion.div
                    className="p-8 md:p-12"
                    initial={{ opacity: 0, x: -20 }}
                    whileInView={{ opacity: 1, x: 0 }}
                    viewport={{ once: true }}
                    transition={{ delay: 0.6, duration: 0.6 }}
                  >
                    <motion.div
                      className="mb-4 inline-block p-3 bg-emerald-500/20 rounded-xl"
                      whileHover={{ rotate: 10 }}
                    >
                      <ShoppingCart className="h-6 w-6 text-emerald-400" />
                    </motion.div>
                    <h3 className="text-2xl font-bold mb-4">{t("multiStoreLists") || "Multi-Store Lists"}</h3>
                    <p className="text-slate-300 mb-6">
                      {t("organizeDescription") ||
                        "Organize shopping lists by store and share with your partner. Keep everything neatly categorized."}
                    </p>
                    <ul className="space-y-3">
                      {[
                        t("createUnlimitedLists") || "Create unlimited lists",
                        t("organizeByStore") || "Organize by store",
                        t("shareWithFamily") || "Share with family",
                      ].map((item, i) => (
                        <motion.li
                          key={i}
                          className="flex items-center"
                          initial={{ opacity: 0, x: -10 }}
                          whileInView={{ opacity: 1, x: 0 }}
                          viewport={{ once: true }}
                          transition={{ delay: 0.7 + i * 0.1, duration: 0.5 }}
                        >
                          <motion.div
                            animate={{ scale: [1, 1.2, 1] }}
                            transition={{ duration: 2, delay: i * 0.5, repeat: Number.POSITIVE_INFINITY }}
                          >
                            <Check className="h-5 w-5 text-emerald-500 mr-3" />
                          </motion.div>
                          <span>{item}</span>
                        </motion.li>
                      ))}
                    </ul>
                  </motion.div>
                  <motion.div
                    className="bg-slate-800 h-full p-8 flex items-center justify-center"
                    initial={{ opacity: 0, x: 20 }}
                    whileInView={{ opacity: 1, x: 0 }}
                    viewport={{ once: true }}
                    transition={{ delay: 0.6, duration: 0.6 }}
                  >
                    <motion.div
                      className="relative w-full max-w-xs aspect-[3/4] rounded-lg overflow-hidden border border-slate-700"
                      whileHover={{
                        y: -10,
                        boxShadow:
                          "0 20px 25px -5px rgba(16, 185, 129, 0.1), 0 10px 10px -5px rgba(16, 185, 129, 0.04)",
                      }}
                      transition={{ type: "spring", stiffness: 300 }}
                    >
                      <Image
                        src="/placeholder.svg?height=400&width=300"
                        alt={t("organizeFeature") || "Organize feature"}
                        fill
                        className="object-cover"
                      />
                      <motion.div
                        className="absolute inset-0 bg-gradient-to-t from-emerald-900/50 to-transparent"
                        initial={{ opacity: 0 }}
                        whileInView={{ opacity: 1 }}
                        viewport={{ once: true }}
                        transition={{ delay: 0.8, duration: 0.6 }}
                      />
                      <motion.div
                        className="absolute bottom-4 left-4 right-4 bg-white/10 backdrop-blur-sm rounded-lg p-3 border border-white/10"
                        initial={{ y: 20, opacity: 0 }}
                        whileInView={{ y: 0, opacity: 1 }}
                        viewport={{ once: true }}
                        transition={{ delay: 1, duration: 0.6 }}
                      >
                        <div className="flex items-center gap-2">
                          <div className="w-4 h-4 rounded-full bg-emerald-500"></div>
                          <p className="text-white text-sm font-medium">
                            {t("organizeByStore") || "Organize by store"}
                          </p>
                        </div>
                      </motion.div>
                    </motion.div>
                  </motion.div>
                </div>
              </TabsContent>

              <TabsContent value="sync" className="p-0 m-0">
                <div className="grid grid-cols-1 md:grid-cols-2 items-center">
                  <motion.div
                    className="p-8 md:p-12"
                    initial={{ opacity: 0, x: -20 }}
                    whileInView={{ opacity: 1, x: 0 }}
                    viewport={{ once: true }}
                    transition={{ delay: 0.6, duration: 0.6 }}
                  >
                    <motion.div
                      className="mb-4 inline-block p-3 bg-teal-500/20 rounded-xl"
                      animate={{ rotate: [0, 10, -10, 0] }}
                      transition={{ duration: 2, repeat: Number.POSITIVE_INFINITY, repeatDelay: 1 }}
                    >
                      <Zap className="h-6 w-6 text-teal-400" />
                    </motion.div>
                    <h3 className="text-2xl font-bold mb-4">{t("realTimeSync") || "Real-Time Sync"}</h3>
                    <p className="text-slate-300 mb-6">
                      {t("syncDescription") ||
                        "Changes update instantly between devices using Supabase. Never lose your lists again."}
                    </p>
                    <ul className="space-y-3">
                      {[
                        t("instantUpdates") || "Instant updates",
                        t("crossDeviceSync") || "Cross-device sync",
                        t("offlineSupport") || "Offline support",
                      ].map((item, i) => (
                        <motion.li
                          key={i}
                          className="flex items-center"
                          initial={{ opacity: 0, x: -10 }}
                          whileInView={{ opacity: 1, x: 0 }}
                          viewport={{ once: true }}
                          transition={{ delay: 0.7 + i * 0.1, duration: 0.5 }}
                        >
                          <motion.div
                            animate={{ scale: [1, 1.2, 1] }}
                            transition={{ duration: 2, delay: i * 0.5, repeat: Number.POSITIVE_INFINITY }}
                          >
                            <Check className="h-5 w-5 text-emerald-500 mr-3" />
                          </motion.div>
                          <span>{item}</span>
                        </motion.li>
                      ))}
                    </ul>
                  </motion.div>
                  <motion.div
                    className="bg-slate-800 h-full p-8 flex items-center justify-center"
                    initial={{ opacity: 0, x: 20 }}
                    whileInView={{ opacity: 1, x: 0 }}
                    viewport={{ once: true }}
                    transition={{ delay: 0.6, duration: 0.6 }}
                  >
                    <motion.div
                      className="relative w-full max-w-xs aspect-[3/4] rounded-lg overflow-hidden border border-slate-700"
                      whileHover={{
                        y: -10,
                        boxShadow:
                          "0 20px 25px -5px rgba(20, 184, 166, 0.1), 0 10px 10px -5px rgba(20, 184, 166, 0.04)",
                      }}
                      transition={{ type: "spring", stiffness: 300 }}
                    >
                      <Image
                        src="/placeholder.svg?height=400&width=300"
                        alt={t("syncFeature") || "Sync feature"}
                        fill
                        className="object-cover"
                      />
                      <motion.div
                        className="absolute inset-0 bg-gradient-to-t from-teal-900/50 to-transparent"
                        initial={{ opacity: 0 }}
                        whileInView={{ opacity: 1 }}
                        viewport={{ once: true }}
                        transition={{ delay: 0.8, duration: 0.6 }}
                      />
                      <motion.div
                        className="absolute top-0 left-0 right-0 p-4 flex justify-center"
                        initial={{ y: -20, opacity: 0 }}
                        whileInView={{ y: 0, opacity: 1 }}
                        viewport={{ once: true }}
                        transition={{ delay: 1, duration: 0.6 }}
                      >
                        <motion.div
                          className="flex items-center gap-2 bg-white/10 backdrop-blur-sm rounded-full px-3 py-1 border border-white/10"
                          animate={{ y: [0, -5, 0] }}
                          transition={{ duration: 2, repeat: Number.POSITIVE_INFINITY }}
                        >
                          <div className="w-2 h-2 rounded-full bg-teal-400"></div>
                          <p className="text-white text-xs">Syncing...</p>
                        </motion.div>
                      </motion.div>
                    </motion.div>
                  </motion.div>
                </div>
              </TabsContent>

              <TabsContent value="track" className="p-0 m-0">
                <div className="grid grid-cols-1 md:grid-cols-2 items-center">
                  <motion.div
                    className="p-8 md:p-12"
                    initial={{ opacity: 0, x: -20 }}
                    whileInView={{ opacity: 1, x: 0 }}
                    viewport={{ once: true }}
                    transition={{ delay: 0.6, duration: 0.6 }}
                  >
                    <motion.div
                      className="mb-4 inline-block p-3 bg-emerald-500/20 rounded-xl"
                      whileHover={{ scale: 1.1 }}
                    >
                      <Check className="h-6 w-6 text-emerald-400" />
                    </motion.div>
                    <h3 className="text-2xl font-bold mb-4">{t("smartLists") || "Smart Lists"}</h3>
                    <p className="text-slate-300 mb-6">
                      {t("trackDescription") ||
                        "Track what's purchased, filter offers, and stay organized with our intelligent list management."}
                    </p>
                    <ul className="space-y-3">
                      {[
                        t("purchaseTracking") || "Purchase tracking",
                        t("smartFiltering") || "Smart filtering",
                        t("shoppingHistory") || "Shopping history",
                      ].map((item, i) => (
                        <motion.li
                          key={i}
                          className="flex items-center"
                          initial={{ opacity: 0, x: -10 }}
                          whileInView={{ opacity: 1, x: 0 }}
                          viewport={{ once: true }}
                          transition={{ delay: 0.7 + i * 0.1, duration: 0.5 }}
                        >
                          <motion.div
                            animate={{ scale: [1, 1.2, 1] }}
                            transition={{ duration: 2, delay: i * 0.5, repeat: Number.POSITIVE_INFINITY }}
                          >
                            <Check className="h-5 w-5 text-emerald-500 mr-3" />
                          </motion.div>
                          <span>{item}</span>
                        </motion.li>
                      ))}
                    </ul>
                  </motion.div>
                  <motion.div
                    className="bg-slate-800 h-full p-8 flex items-center justify-center"
                    initial={{ opacity: 0, x: 20 }}
                    whileInView={{ opacity: 1, x: 0 }}
                    viewport={{ once: true }}
                    transition={{ delay: 0.6, duration: 0.6 }}
                  >
                    <motion.div
                      className="relative w-full max-w-xs aspect-[3/4] rounded-lg overflow-hidden border border-slate-700"
                      whileHover={{
                        y: -10,
                        boxShadow:
                          "0 20px 25px -5px rgba(16, 185, 129, 0.1), 0 10px 10px -5px rgba(16, 185, 129, 0.04)",
                      }}
                      transition={{ type: "spring", stiffness: 300 }}
                    >
                      <Image
                        src="/placeholder.svg?height=400&width=300"
                        alt={t("trackFeature") || "Track feature"}
                        fill
                        className="object-cover"
                      />
                      <motion.div
                        className="absolute inset-0 bg-gradient-to-t from-emerald-900/50 to-transparent"
                        initial={{ opacity: 0 }}
                        whileInView={{ opacity: 1 }}
                        viewport={{ once: true }}
                        transition={{ delay: 0.8, duration: 0.6 }}
                      />
                      <motion.div
                        className="absolute inset-0 flex items-center justify-center"
                        initial={{ scale: 0.8, opacity: 0 }}
                        whileInView={{ scale: 1, opacity: 1 }}
                        viewport={{ once: true }}
                        transition={{ delay: 1, duration: 0.6 }}
                      >
                        <motion.div
                          className="bg-white/10 backdrop-blur-sm rounded-lg p-4 border border-white/10 max-w-[80%]"
                          whileHover={{ scale: 1.05 }}
                        >
                          <div className="space-y-2">
                            {[1, 2, 3].map((item) => (
                              <motion.div
                                key={item}
                                className="flex items-center gap-2"
                                initial={{ opacity: 0, x: -10 }}
                                whileInView={{ opacity: 1, x: 0 }}
                                viewport={{ once: true }}
                                transition={{ delay: 1 + item * 0.1, duration: 0.4 }}
                              >
                                <div className="w-4 h-4 rounded-full bg-emerald-500 flex-shrink-0"></div>
                                <p className="text-white text-xs">
                                  {t("itemTracked") || `Item ${item} tracked`}
                                </p>
                              </motion.div>
                            ))}
                          </div>
                        </motion.div>
                      </motion.div>
                    </motion.div>
                  </motion.div>
                </div>
              </TabsContent>

              <TabsContent value="save" className="p-0 m-0">
                <div className="grid grid-cols-1 md:grid-cols-2 items-center">
                  <motion.div
                    className="p-8 md:p-12"
                    initial={{ opacity: 0, x: -20 }}
                    whileInView={{ opacity: 1, x: 0 }}
                    viewport={{ once: true }}
                    transition={{ delay: 0.6, duration: 0.6 }}
                  >
                    <motion.div
                      className="mb-4 inline-block p-3 bg-teal-500/20 rounded-xl"
                      animate={{ scale: [1, 1.1, 1] }}
                      transition={{ duration: 2, repeat: Number.POSITIVE_INFINITY }}
                    >
                      <Bell className="h-6 w-6 text-teal-400" />
                    </motion.div>
                    <h3 className="text-2xl font-bold mb-4">{t("priceAlerts") || "Price Alerts"}</h3>
                    <p className="text-slate-300 mb-6">
                      {t("saveDescription") ||
                        "Get notified about discounts and deals at your favorite stores. Never miss a sale again."}
                    </p>
                    <ul className="space-y-3">
                      {[
                        t("customPriceAlerts") || "Custom price alerts",
                        t("saleNotifications") || "Sale notifications",
                        t("dealRecommendations") || "Deal recommendations",
                      ].map((item, i) => (
                        <motion.li
                          key={i}
                          className="flex items-center"
                          initial={{ opacity: 0, x: -10 }}
                          whileInView={{ opacity: 1, x: 0 }}
                          viewport={{ once: true }}
                          transition={{ delay: 0.7 + i * 0.1, duration: 0.5 }}
                        >
                          <motion.div
                            animate={{ scale: [1, 1.2, 1] }}
                            transition={{ duration: 2, delay: i * 0.5, repeat: Number.POSITIVE_INFINITY }}
                          >
                            <Check className="h-5 w-5 text-emerald-500 mr-3" />
                          </motion.div>
                          <span>{item}</span>
                        </motion.li>
                      ))}
                    </ul>
                  </motion.div>
                  <motion.div
                    className="bg-slate-800 h-full p-8 flex items-center justify-center"
                    initial={{ opacity: 0, x: 20 }}
                    whileInView={{ opacity: 1, x: 0 }}
                    viewport={{ once: true }}
                    transition={{ delay: 0.6, duration: 0.6 }}
                  >
                    <motion.div
                      className="relative w-full max-w-xs aspect-[3/4] rounded-lg overflow-hidden border border-slate-700"
                      whileHover={{
                        y: -10,
                        boxShadow:
                          "0 20px 25px -5px rgba(20, 184, 166, 0.1), 0 10px 10px -5px rgba(20, 184, 166, 0.04)",
                      }}
                      transition={{ type: "spring", stiffness: 300 }}
                    >
                      <Image
                        src="/placeholder.svg?height=400&width=300"
                        alt={t("saveFeature") || "Save feature"}
                        fill
                        className="object-cover"
                      />
                      <motion.div
                        className="absolute inset-0 bg-gradient-to-t from-teal-900/50 to-transparent"
                        initial={{ opacity: 0 }}
                        whileInView={{ opacity: 1 }}
                        viewport={{ once: true }}
                        transition={{ delay: 0.8, duration: 0.6 }}
                      />
                      <motion.div
                        className="absolute top-4 right-4"
                        initial={{ scale: 0, opacity: 0 }}
                        whileInView={{ scale: 1, opacity: 1 }}
                        viewport={{ once: true }}
                        transition={{ delay: 1, duration: 0.6, type: "spring" }}
                      >
                        <motion.div
                          className="bg-red-500/80 backdrop-blur-sm rounded-full p-2"
                          animate={{ scale: [1, 1.2, 1] }}
                          transition={{ duration: 1.5, repeat: Number.POSITIVE_INFINITY }}
                        >
                          <Bell className="h-5 w-5 text-white" />
                        </motion.div>
                      </motion.div>
                      <motion.div
                        className="absolute bottom-4 left-4 right-4 bg-white/10 backdrop-blur-sm rounded-lg p-3 border border-white/10"
                        initial={{ y: 20, opacity: 0 }}
                        whileInView={{ y: 0, opacity: 1 }}
                        viewport={{ once: true }}
                        transition={{ delay: 1.2, duration: 0.6 }}
                      >
                        <div className="space-y-1">
                          <p className="text-white text-xs font-medium">{t("priceDropAlert") || "Price Drop Alert!"}</p>
                          <div className="flex items-center justify-between">
                            <p className="text-teal-300 text-xs">$4.99</p>
                            <p className="text-white text-xs line-through opacity-70">$7.99</p>
                          </div>
                        </div>
                      </motion.div>
                    </motion.div>
                  </motion.div>
                </div>
              </TabsContent>
            </motion.div>
          </Tabs>
        </div>
      </section>

      {/* Testimonials Section */}
      <section className="py-24 bg-slate-900/30 relative overflow-hidden">
        {/* Background elements */}
        <div className="absolute inset-0 overflow-hidden">
          <svg
            className="absolute left-[max(50%,25rem)] top-0 h-[64rem] w-[128rem] -translate-x-1/2 stroke-slate-700 [mask-image:radial-gradient(64rem_64rem_at_top,white,transparent)]"
            aria-hidden="true"
          >
            <defs>
              <pattern
                id="grid-pattern"
                width="40"
                height="40"
                patternUnits="userSpaceOnUse"
                patternTransform="rotate(12)"
              >
                <rect width="100%" height="100%" fill="none" />
                <path d="M0 20 L40 20" stroke="currentColor" strokeWidth="0.2" />
                <path d="M20 0 L20 40" stroke="currentColor" strokeWidth="0.2" />
              </pattern>
            </defs>
            <rect width="100%" height="100%" fill="url(#grid-pattern)" />
          </svg>
        </div>

        <div className="container mx-auto px-6 relative z-10">
          <motion.div
            className="text-center max-w-3xl mx-auto mb-16"
            initial={{ opacity: 0, y: 20 }}
            whileInView={{ opacity: 1, y: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.6 }}
          >
            <motion.div
              initial={{ scale: 0.9, opacity: 0 }}
              whileInView={{ scale: 1, opacity: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.5 }}
            >
              <Badge className="px-4 py-1.5 text-sm font-medium bg-slate-800 text-slate-300 border-slate-700 mb-4">
                {t("testimonials") || "Testimonials"}
              </Badge>
            </motion.div>
            <motion.h2
              className="text-4xl font-bold mb-6"
              initial={{ opacity: 0 }}
              whileInView={{ opacity: 1 }}
              viewport={{ once: true }}
              transition={{ delay: 0.2, duration: 0.6 }}
            >
              {t("testimonialsTitle") || "Loved by shoppers everywhere"}
            </motion.h2>
            <motion.p
              className="text-slate-400 text-lg"
              initial={{ opacity: 0 }}
              whileInView={{ opacity: 1 }}
              viewport={{ once: true }}
              transition={{ delay: 0.3, duration: 0.6 }}
            >
              {t("testimonialsSubtitle") ||
                "See what our users have to say about how our app has transformed their shopping experience."}
            </motion.p>
          </motion.div>

          <div className="grid grid-cols-1 md:grid-cols-3 gap-8 max-w-6xl mx-auto">
            {[
              {
                name: "Sarah M.",
                role: t("busyParent") || "Busy Parent",
                avatar: "/placeholder.svg?height=100&width=100",
                text:
                  t("testimonial1") ||
                  "This app has saved me so much time! I love how I can share lists with my husband in real-time.",
                rating: 5,
              },
              {
                name: "James T.",
                role: t("budgetShopper") || "Budget Shopper",
                avatar: "/placeholder.svg?height=100&width=100",
                text: t("testimonial2") || "The smart lists feature is a game-changer. I never miss a deal now!",
                rating: 4,
              },
              {
                name: "Emily R.",
                role: t("mealPlanner") || "Meal Planner",
                avatar: "/placeholder.svg?height=100&width=100",
                text: t("testimonial3") || "Super easy to use and keeps my shopping organized across multiple stores.",
                rating: 5,
              },
            ].map((testimonial, i) => (
              <motion.div
                key={i}
                initial={{ opacity: 0, y: 20 }}
                whileInView={{ opacity: 1, y: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.5, delay: i * 0.1 }}
                whileHover={{
                  y: -10,
                  boxShadow: "0 20px 25px -5px rgba(16, 185, 129, 0.1), 0 10px 10px -5px rgba(16, 185, 129, 0.04)",
                }}
                className="bg-gradient-to-b from-slate-800 to-slate-900 rounded-2xl border border-slate-700 p-8 shadow-xl transition-all duration-300 relative overflow-hidden"
              >
                {/* Decorative elements */}
                <motion.div
                  className="absolute -top-20 -right-20 w-40 h-40 bg-emerald-500/5 rounded-full blur-3xl"
                  animate={{ scale: [1, 1.2, 1] }}
                  transition={{ duration: 4, repeat: Number.POSITIVE_INFINITY, repeatType: "reverse" }}
                />

                <motion.div
                  className="flex items-center mb-4"
                  initial={{ opacity: 0 }}
                  whileInView={{ opacity: 1 }}
                  viewport={{ once: true }}
                  transition={{ delay: 0.2 + i * 0.1, duration: 0.5 }}
                >
                  {[...Array(5)].map((_, j) => (
                    <motion.div
                      key={j}
                      initial={{ opacity: 0, scale: 0 }}
                      whileInView={{ opacity: 1, scale: 1 }}
                      viewport={{ once: true }}
                      transition={{ delay: 0.3 + i * 0.1 + j * 0.05, duration: 0.3 }}
                      whileHover={{ scale: 1.2, rotate: 5 }}
                    >
                      <Star
                        className={`w-5 h-5 ${j < testimonial.rating ? "text-yellow-400 fill-yellow-400" : "text-slate-600"}`}
                      />
                    </motion.div>
                  ))}
                </motion.div>

                <motion.div
                  initial={{ opacity: 0 }}
                  whileInView={{ opacity: 1 }}
                  viewport={{ once: true }}
                  transition={{ delay: 0.4 + i * 0.1, duration: 0.5 }}
                >
                  <motion.div initial={{ scale: 0.95 }} whileHover={{ scale: 1 }}>
                    <p className="text-slate-300 mb-6 italic relative">
                      <span className="absolute -top-4 -left-2 text-4xl text-emerald-500/20">"</span>
                      {testimonial.text}
                      <span className="absolute -bottom-8 -right-2 text-4xl text-emerald-500/20">"</span>
                    </p>
                  </motion.div>
                </motion.div>

                <motion.div
                  className="flex items-center"
                  initial={{ opacity: 0, y: 10 }}
                  whileInView={{ opacity: 1, y: 0 }}
                  viewport={{ once: true }}
                  transition={{ delay: 0.5 + i * 0.1, duration: 0.5 }}
                >
                  <motion.div
                    className="relative w-12 h-12 rounded-full overflow-hidden mr-4 border-2 border-slate-700"
                    whileHover={{ scale: 1.1, borderColor: "#10b981" }}
                  >
                    <Image
                      src={testimonial.avatar || "/placeholder.svg"}
                      alt={testimonial.name}
                      fill
                      className="object-cover"
                    />
                  </motion.div>
                  <div>
                    <p className="font-semibold">{testimonial.name}</p>
                    <p className="text-sm text-slate-400">{testimonial.role}</p>
                  </div>
                </motion.div>
              </motion.div>
            ))}
          </div>
        </div>
      </section>

      {/* FAQ Section */}
      <section className="py-24 relative overflow-hidden">
        {/* Background elements */}
        <div className="absolute inset-0 overflow-hidden">
          <motion.div
            className="absolute -top-[10%] -right-[10%] w-[40%] h-[40%] bg-emerald-500/5 rounded-full blur-3xl"
            animate={{ scale: [1, 1.2, 1], opacity: [0.3, 0.2, 0.3] }}
            transition={{ duration: 8, repeat: Number.POSITIVE_INFINITY, repeatType: "reverse" }}
          />
          <motion.div
            className="absolute -bottom-[10%] -left-[10%] w-[30%] h-[30%] bg-teal-500/5 rounded-full blur-3xl"
            animate={{ scale: [1, 1.3, 1], opacity: [0.2, 0.3, 0.2] }}
            transition={{ duration: 10, repeat: Number.POSITIVE_INFINITY, repeatType: "reverse", delay: 1 }}
          />
        </div>

        <div className="container mx-auto px-6 relative z-10">
          <motion.div
            className="text-center max-w-3xl mx-auto mb-16"
            initial={{ opacity: 0, y: 20 }}
            whileInView={{ opacity: 1, y: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.6 }}
          >
            <motion.div
              initial={{ scale: 0.9, opacity: 0 }}
              whileInView={{ scale: 1, opacity: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.5 }}
            >
              <Badge className="px-4 py-1.5 text-sm font-medium bg-slate-800 text-slate-300 border-slate-700 mb-4">
                {t("faq") || "FAQ"}
              </Badge>
            </motion.div>
            <motion.h2
              className="text-4xl font-bold mb-6"
              initial={{ opacity: 0 }}
              whileInView={{ opacity: 1 }}
              viewport={{ once: true }}
              transition={{ delay: 0.2, duration: 0.6 }}
            >
              {t("faqTitle") || "Frequently Asked Questions"}
            </motion.h2>
            <motion.p
              className="text-slate-400 text-lg"
              initial={{ opacity: 0 }}
              whileInView={{ opacity: 1 }}
              viewport={{ once: true }}
              transition={{ delay: 0.3, duration: 0.6 }}
            >
              {t("faqSubtitle") || "Everything you need to know about our shopping list app."}
            </motion.p>
          </motion.div>

          <div className="max-w-3xl mx-auto space-y-6">
            {[
              {
                q: t("faqSync") || "How does real-time sync work?",
                a:
                  t("faqSyncAnswer") ||
                  "Our app uses Supabase to sync your lists instantly across devices, so everyone stays updated.",
                icon: "Zap",
              },
              {
                q: t("faqShare") || "Can I share lists with others?",
                a:
                  t("faqShareAnswer") ||
                  "Yes! You can share lists with family or friends, and they can edit them in real-time.",
                icon: "Share",
              },
              {
                q: t("faqSecurity") || "Is my data secure?",
                a:
                  t("faqSecurityAnswer") ||
                  "We use industry-standard encryption to protect your data and ensure privacy.",
                icon: "Shield",
              },
              {
                q: t("faqMobile") || "Is there a mobile app?",
                a:
                  t("faqMobileAnswer") ||
                  "Yes, we have native apps for iOS and Android that sync with your web account.",
                icon: "Smartphone",
              },
              {
                q: t("faqCost") || "How much does it cost?",
                a:
                  t("faqCostAnswer") ||
                  "We offer a generous free plan with all essential features. Premium plans start at $4.99/month.",
                icon: "CreditCard",
              },
            ].map((faq, i) => (
              <motion.div
                key={i}
                initial={{ opacity: 0, y: 10 }}
                whileInView={{ opacity: 1, y: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.3, delay: i * 0.1 }}
                whileHover={{ scale: 1.02 }}
                className="p-6 bg-slate-800/50 rounded-xl border border-slate-700 hover:border-slate-600 transition-all duration-300 relative overflow-hidden group"
              >
                {/* Decorative gradient */}
                <div className="absolute inset-0 bg-gradient-to-r from-emerald-500/5 to-teal-500/5 opacity-0 group-hover:opacity-100 transition-opacity duration-300" />

                <div className="flex items-start gap-4">
                  <motion.div
                    className="mt-1 p-2 rounded-lg bg-emerald-500/10 text-emerald-400"
                    whileHover={{ rotate: [0, -10, 10, -10, 0] }}
                    transition={{ duration: 0.5 }}
                  >
                    {faq.icon === "Zap" && <Zap className="h-5 w-5" />}
                    {faq.icon === "Share" && <Share className="h-5 w-5" />}
                    {faq.icon === "Shield" && <Shield className="h-5 w-5" />}
                    {faq.icon === "Smartphone" && <Smartphone className="h-5 w-5" />}
                    {faq.icon === "CreditCard" && <CreditCard className="h-5 w-5" />}
                  </motion.div>
                  <div className="space-y-2">
                    <motion.h3
                      className="text-xl font-semibold"
                      initial={{ opacity: 0 }}
                      whileInView={{ opacity: 1 }}
                      viewport={{ once: true }}
                      transition={{ delay: 0.1 + i * 0.1, duration: 0.3 }}
                    >
                      {faq.q}
                    </motion.h3>
                    <motion.p
                      className="text-slate-300"
                      initial={{ opacity: 0 }}
                      whileInView={{ opacity: 1 }}
                      viewport={{ once: true }}
                      transition={{ delay: 0.2 + i * 0.1, duration: 0.3 }}
                    >
                      {faq.a}
                    </motion.p>
                  </div>
                </div>
              </motion.div>
            ))}
          </div>
        </div>
      </section>

      {/* Contact Support Section */}
      <section className="py-16 relative overflow-hidden">
        {/* Background elements */}
        <div className="absolute inset-0 overflow-hidden">
          <div className="absolute inset-0 bg-gradient-to-r from-slate-50 to-white dark:from-slate-950 dark:to-slate-900 opacity-80"></div>
          <div
            className="absolute inset-0"
            style={{
              backgroundImage:
                "url(\"data:image/svg+xml,%3Csvg width='30' height='30' viewBox='0 0 30 30' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M15 0C6.716 0 0 6.716 0 15c0 8.284 6.716 15 15 15 8.284 0 15-6.716 15-15 0-8.284-6.716-15-15-15zm0 5c5.514 0 10 4.486 10 10s-4.486 10-10 10S5 20.514 5 15 9.486 5 15 5z' fill='%2310b981' fillOpacity='0.05' fillRule='evenodd'/%3E%3C/svg%3E\")",
              backgroundSize: "30px 30px",
            }}
          ></div>
        </div>

        <div className="container mx-auto px-6 relative z-10">
          <motion.div
            className="max-w-4xl mx-auto bg-white dark:bg-slate-800 rounded-2xl shadow-xl overflow-hidden"
            initial={{ opacity: 0, y: 20 }}
            whileInView={{ opacity: 1, y: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.6 }}
          >
            <div className="grid grid-cols-1 md:grid-cols-2">
              <div className="p-8 md:p-12 bg-gradient-to-br from-emerald-500 to-teal-600 text-white">
                <motion.div
                  initial={{ opacity: 0, y: 10 }}
                  whileInView={{ opacity: 1, y: 0 }}
                  viewport={{ once: true }}
                  transition={{ delay: 0.2, duration: 0.6 }}
                >
                  <h3 className="text-3xl font-bold mb-4">{t("stillHaveQuestions") || "Still have questions?"}</h3>
                  <p className="text-emerald-50 mb-6">
                    {t("supportTeamDescription") ||
                      "Our support team is here to help you with any questions or concerns you might have about our app."}
                  </p>

                  <div className="space-y-4">
                    <div className="flex items-start gap-3">
                      <div className="p-2 bg-white/20 rounded-full mt-0.5">
                        <motion.div whileHover={{ rotate: 15 }} transition={{ type: "spring", stiffness: 300 }}>
                          <Mail className="h-4 w-4" />
                        </motion.div>
                      </div>
                      <div>
                        <p className="font-medium">{t("emailUs") || "Email Us"}</p>
                        <p className="text-sm text-emerald-100">support@groceryapp.com</p>
                      </div>
                    </div>

                    <div className="flex items-start gap-3">
                      <div className="p-2 bg-white/20 rounded-full mt-0.5">
                        <motion.div
                          animate={{ rotate: [0, 5, 0, -5, 0] }}
                          transition={{ duration: 2, repeat: Number.POSITIVE_INFINITY, repeatDelay: 3 }}
                        >
                          <Phone className="h-4 w-4" />
                        </motion.div>
                      </div>
                      <div>
                        <p className="font-medium">{t("callUs") || "Call Us"}</p>
                        <p className="text-sm text-emerald-100">+1 (555) 123-4567</p>
                      </div>
                    </div>

                    <div className="flex items-start gap-3">
                      <div className="p-2 bg-white/20 rounded-full mt-0.5">
                        <motion.div whileHover={{ scale: 1.2 }}>
                          <MessageSquare className="h-4 w-4" />
                        </motion.div>
                      </div>
                      <div>
                        <p className="font-medium">{t("liveChat") || "Live Chat"}</p>
                        <p className="text-sm text-emerald-100">{t("available24/7") || "Available 24/7"}</p>
                      </div>
                    </div>
                  </div>
                </motion.div>
              </div>

              <div className="p-8 md:p-12 bg-white dark:bg-slate-800">
                <motion.div
                  initial={{ opacity: 0, y: 10 }}
                  whileInView={{ opacity: 1, y: 0 }}
                  viewport={{ once: true }}
                  transition={{ delay: 0.4, duration: 0.6 }}
                >
                  <h3 className="text-2xl font-bold mb-6 text-slate-900 dark:text-white">
                    {t("sendUsMessage") || "Send us a message"}
                  </h3>

                  <div className="space-y-4">
                    <div className="space-y-2">
                      <Label htmlFor="name" className="text-slate-700 dark:text-slate-300">
                        {t("name") || "Name"}
                      </Label>
                      <Input
                        id="name"
                        placeholder={t("yourName") || "Your name"}
                        className="border-slate-200 dark:border-slate-700 dark:bg-slate-900 dark:text-slate-200 focus-visible:ring-emerald-500"
                      />
                    </div>

                    <div className="space-y-2">
                      <Label htmlFor="email" className="text-slate-700 dark:text-slate-300">
                        {t("email") || "Email"}
                      </Label>
                      <Input
                        id="email"
                        type="email"
                        placeholder={t("yourEmail") || "Your email"}
                        className="border-slate-200 dark:border-slate-700 dark:bg-slate-900 dark:text-slate-200 focus-visible:ring-emerald-500"
                      />
                    </div>

                    <div className="space-y-2">
                      <Label htmlFor="message" className="text-slate-700 dark:text-slate-300">
                        {t("message") || "Message"}
                      </Label>
                      <Textarea
                        id="message"
                        placeholder={t("howCanWeHelp") || "How can we help?"}
                        className="min-h-[120px] border-slate-200 dark:border-slate-700 dark:bg-slate-900 dark:text-slate-200 focus-visible:ring-emerald-500"
                      />
                    </div>

                    <motion.div className="pt-4" whileHover={{ scale: 1.02 }} whileTap={{ scale: 0.98 }}>
                      <Button className="w-full bg-gradient-to-r from-emerald-600 to-teal-600 hover:from-emerald-700 hover:to-teal-700 text-white">
                        <Send className="mr-2 h-4 w-4" />
                        {t("sendMessage") || "Send Message"}
                      </Button>
                    </motion.div>
                  </div>
                </motion.div>
              </div>
            </div>
          </motion.div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="py-20 relative overflow-hidden">
        <div className="absolute inset-0 z-0">
          <motion.div
            className="absolute top-0 left-1/4 w-96 h-96 bg-emerald-500 rounded-full filter blur-3xl opacity-20"
            animate={{ scale: [1, 1.2, 1], opacity: [0.2, 0.3, 0.2] }}
            transition={{ duration: 8, repeat: Number.POSITIVE_INFINITY }}
          />
          <motion.div
            className="absolute bottom-0 right-1/4 w-96 h-96 bg-teal-500 rounded-full filter blur-3xl opacity-20"
            animate={{ scale: [1, 1.3, 1], opacity: [0.2, 0.15, 0.2] }}
            transition={{ duration: 10, repeat: Number.POSITIVE_INFINITY, delay: 1 }}
          />

          {/* Animated particles */}
          <div className="absolute inset-0 overflow-hidden">
            {[...Array(10)].map((_, i) => (
              <motion.div
                key={i}
                className="absolute rounded-full"
                style={{
                  width: Math.random() * 6 + 2,
                  height: Math.random() * 6 + 2,
                  backgroundColor: i % 2 === 0 ? "#10b981" : "#14b8a6",
                  top: `${Math.random() * 100}%`,
                  left: `${Math.random() * 100}%`,
                }}
                animate={{
                  y: [0, Math.random() * -100 - 50],
                  opacity: [0, 0.7, 0],
                }}
                transition={{
                  duration: Math.random() * 5 + 5,
                  repeat: Number.POSITIVE_INFINITY,
                  repeatType: "loop",
                  ease: "easeInOut",
                  delay: Math.random() * 5,
                }}
              />
            ))}
          </div>
        </div>

        <div className="container mx-auto px-6 relative z-10">
          <motion.div
            className="max-w-4xl mx-auto bg-gradient-to-r from-slate-900 to-slate-800 rounded-3xl p-12 border border-slate-700 shadow-2xl relative overflow-hidden"
            initial={{ opacity: 0, y: 20 }}
            whileInView={{ opacity: 1, y: 0 }}
            viewport={{ once: true }}
            transition={{ duration: 0.6 }}
          >
            {/* Decorative elements */}
            <div className="absolute top-0 right-0 w-40 h-40 bg-emerald-500/10 rounded-bl-full"></div>
            <div className="absolute bottom-0 left-0 w-40 h-40 bg-teal-500/10 rounded-tr-full"></div>

            <motion.div
              className="text-center mb-10 relative"
              initial={{ opacity: 0 }}
              whileInView={{ opacity: 1 }}
              viewport={{ once: true }}
              transition={{ delay: 0.2, duration: 0.6 }}
            >
              <motion.h2
                className="text-4xl font-bold mb-4"
                initial={{ y: 20 }}
                whileInView={{ y: 0 }}
                viewport={{ once: true }}
                transition={{ delay: 0.3, duration: 0.6 }}
              >
                {t("readyToSimplify") || "Ready to simplify your shopping?"}
              </motion.h2>
              <motion.p
                className="text-xl text-slate-300"
                initial={{ y: 20 }}
                whileInView={{ y: 0 }}
                viewport={{ once: true }}
                transition={{ delay: 0.4, duration: 0.6 }}
              >
                {t("joinThousands") || "Join thousands of happy shoppers today."}
              </motion.p>
            </motion.div>

            <motion.div
              className="flex flex-col sm:flex-row justify-center gap-4"
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              viewport={{ once: true }}
              transition={{ delay: 0.5, duration: 0.6 }}
            >
              <motion.div whileHover={{ scale: 1.05 }} whileTap={{ scale: 0.95 }}>
                <Button
                  size="lg"
                  className="bg-gradient-to-r from-emerald-600 to-teal-600 hover:from-emerald-700 hover:to-teal-700 text-white font-semibold py-6 px-8 rounded-xl shadow-lg hover:shadow-emerald-500/20 transition-all duration-300"
                  onClick={() => router.push("/auth")}
                >
                  <motion.span className="flex items-center">
                    {t("getStarted") || "Get Started Free"}
                    <motion.div
                      animate={{ x: [0, 5, 0] }}
                      transition={{ duration: 1, repeat: Number.POSITIVE_INFINITY, repeatDelay: 1 }}
                    >
                      <ArrowRight className="ml-2 h-5 w-5" />
                    </motion.div>
                  </motion.span>
                </Button>
              </motion.div>

              <motion.div whileHover={{ scale: 1.05 }} whileTap={{ scale: 0.95 }}>
                <Button
                  variant="outline"
                  size="lg"
                  className="border-2 border-slate-700 bg-slate-800/50 text-white hover:bg-slate-700/50 font-semibold py-6 px-8 rounded-xl transition-all duration-300"
                  onClick={() => router.push("/demo")}
                >
                  {t("watchDemo") || "Watch Demo"}
                </Button>
              </motion.div>
            </motion.div>
          </motion.div>
        </div>
      </section>

      {/* Footer */}
      <footer className="bg-slate-950 py-16 border-t border-slate-800 relative overflow-hidden">
        {/* Background pattern */}
        <div className="absolute inset-0 opacity-5">
          <svg width="100%" height="100%" xmlns="http://www.w3.org/2000/svg">
            <defs>
              <pattern id="footer-grid" width="40" height="40" patternUnits="userSpaceOnUse">
                <path
                  d="M0 0 L40 0 L40 40 L0 40 Z"
                  fill="none"
                  stroke="currentColor"
                  strokeWidth="0.5"
                  strokeOpacity="0.3"
                />
              </pattern>
            </defs>
            <rect width="100%" height="100%" fill="url(#footer-grid)" />
          </svg>
        </div>

        <div className="container mx-auto px-6 relative z-10">
          <div className="grid grid-cols-1 md:grid-cols-4 gap-12">
            <motion.div
              className="space-y-4"
              initial={{ opacity: 0, y: 20 }}
              whileInView={{ opacity: 1, y: 0 }}
              viewport={{ once: true }}
              transition={{ duration: 0.6 }}
            >
              <motion.div whileHover={{ scale: 1.05 }} transition={{ type: "spring", stiffness: 400, damping: 10 }}>
                <Image src="/psonio.png" alt={t("logo") || "Logo"} width={128} height={76} className="mb-4" />
              </motion.div>
              <p className="text-slate-400">
                {t("simplifyingGrocery") || "Simplifying grocery shopping for everyone."}
              </p>
              <div className="flex space-x-4 pt-4">
                {[
                  { name: "twitter", icon: Twitter },
                  { name: "facebook", icon: Facebook },
                  { name: "instagram", icon: Instagram },
                  { name: "github", icon: Github },
                ].map((social, i) => (
                  <motion.a
                    key={social.name}
                    href={`#${social.name}`}
                    className="w-10 h-10 flex items-center justify-center rounded-full bg-slate-800 hover:bg-slate-700 transition-colors duration-300"
                    whileHover={{ y: -5, backgroundColor: "#10b981" }}
                    initial={{ opacity: 0, y: 20 }}
                    whileInView={{ opacity: 1, y: 0 }}
                    viewport={{ once: true }}
                    transition={{ duration: 0.3, delay: 0.1 + i * 0.1 }}
                  >
                    <span className="sr-only">{social.name}</span>
                    <social.icon className="h-5 w-5 text-slate-300" />
                  </motion.a>
                ))}
              </div>
            </motion.div>

            {[
              {
                title: t("product") || "Product",
                links: [
                  t("features") || "Features",
                  t("pricing") || "Pricing",
                  t("demo") || "Demo",
                  t("roadmap") || "Roadmap",
                ],
              },
              {
                title: t("company") || "Company",
                links: [
                  t("about") || "About",
                  t("blog") || "Blog",
                  t("careers") || "Careers",
                  t("contact") || "Contact",
                ],
              },
              {
                title: t("legal") || "Legal",
                links: [
                  t("privacyPolicy") || "Privacy Policy",
                  t("termsOfService") || "Terms of Service",
                  t("cookiePolicy") || "Cookie Policy",
                ],
              },
            ].map((column, i) => (
              <motion.div
                key={column.title}
                initial={{ opacity: 0, y: 20 }}
                whileInView={{ opacity: 1, y: 0 }}
                viewport={{ once: true }}
                transition={{ duration: 0.6, delay: 0.2 + i * 0.1 }}
              >
                <h3 className="text-lg font-semibold text-white mb-4">{column.title}</h3>
                <ul className="space-y-3 text-slate-400">
                  {column.links.map((link, j) => (
                    <motion.li
                      key={link}
                      initial={{ opacity: 0, x: -10 }}
                      whileInView={{ opacity: 1, x: 0 }}
                      viewport={{ once: true }}
                      transition={{ duration: 0.3, delay: 0.3 + i * 0.1 + j * 0.05 }}
                    >
                      <motion.a
                        href={`/${link.toLowerCase().replace(/\s+/g, "-")}`}
                        className="hover:text-emerald-400 transition-colors inline-block"
                        whileHover={{ x: 5 }}
                      >
                        {link}
                      </motion.a>
                    </motion.li>
                  ))}
                </ul>
              </motion.div>
            ))}
          </div>

          <motion.div
            className="border-t border-slate-800 mt-12 pt-8 flex flex-col md:flex-row justify-between items-center"
            initial={{ opacity: 0 }}
            whileInView={{ opacity: 1 }}
            viewport={{ once: true }}
            transition={{ delay: 0.6, duration: 0.6 }}
          >
            <motion.p className="text-sm text-slate-500" whileHover={{ color: "#10b981" }}>
              © {new Date().getFullYear()} {t("appName") || "GroceryApp"} –{" "}
              {t("allRightsReserved") || "All rights reserved."}
            </motion.p>
          </motion.div>
        </div>
      </footer>
    </div>
  )
}
